==> bitcoin_0.13.1.orig.tar.gz: bitcoin-0.13.1/src/qt/locale/bitcoin_ku_IQ.ts <==
<TS language="ku_IQ" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>ناوونیشانێکی نوێ دروست بکە</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;نوێ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;ڕوونووس</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;داخستن</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;هەناردن</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;سڕینەوە</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ناردن</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;پەرگە</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;سازکارییەکان</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;یارمەتی</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ئاگاداری</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>زانیاری</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>کۆ:</translation>
    </message>
    <message>
        <source>Priority:</source>
        <translation>لەپێشی:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>تێچوون:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>لەپێشی</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>ناو</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>وەشان</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>بەخێربێن</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>هەڵبژاردنەکان</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Total:</source>
        <translation>گشتی</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;زانیاری</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>ناو</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>وەشان</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;کردنەوە</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;پاککردنەوە</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>گشتییەکان</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>بەڵێ</translation>
    </message>
    <message>
        <source>No</source>
        <translation>نەخێر</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;سەرجەم:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;پەیام:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>پاککردنەوە</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>پیشاندان</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>سڕینەوە</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>کۆ:</translation>
    </message>
    <message>
        <source>Priority:</source>
        <translation>لەپێشی:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>تێچوون:</translation>
    </message>
    <message>
        <source>fast</source>
        <translation>خێرا</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Message:</source>
        <translation>پەیام:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>هەڵبژاردنەکان:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>زانیاری</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ئاگاداری</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
</context>
</TS>

==> bitcoin-0.14.1.tar.gz: bitcoin-0.14.1/src/qt/locale/bitcoin_ku_IQ.ts <==
<TS language="ku_IQ" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>ناوونیشانێکی نوێ دروست بکە</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;نوێ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;ڕوونووس</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;داخستن</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;هەناردن</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;سڕینەوە</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>ناوونیشان</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ناردن</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;پەرگە</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;سازکارییەکان</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;یارمەتی</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ئاگاداری</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>زانیاری</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>کۆ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>تێچوون:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>بەڵێ</translation>
    </message>
    <message>
        <source>no</source>
        <translation>نەخێر</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>ناو</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>وەشان</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>بەخێربێن</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>هەڵبژاردنەکان</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Total:</source>
        <translation>گشتی</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;زانیاری</translation>
    </message>
    <message>
        <source>General</source>
        <translation>گشتی</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تۆڕ</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>ناو</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>نێدرا</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>وەشان</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>خزمەتگوزاریەکان</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;کردنەوە</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;پاککردنەوە</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>گشتییەکان</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>لە ناو</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>لەدەرەوە</translation>
    </message>
    <message>
        <source>1 &amp;hour</source>
        <translation>1&amp;سات</translation>
    </message>
    <message>
        <source>1 &amp;day</source>
        <translation>1&amp;ڕۆژ</translation>
    </message>
    <message>
        <source>1 &amp;week</source>
        <translation>1&amp;هەفتە</translation>
    </message>
    <message>
        <source>1 &amp;year</source>
        <translation>1&amp;ساڵ</translation>
    </message>
    <message>
        <source>never</source>
        <translation>هەرگیز</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>بەڵێ</translation>
    </message>
    <message>
        <source>No</source>
        <translation>نەخێر</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;سەرجەم:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;پەیام:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>پاککردنەوە</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>پیشاندان</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>سڕینەوە</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>ناوونیشان</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation>کۆ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>تێچوون:</translation>
    </message>
    <message>
        <source>fast</source>
        <translation>خێرا</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Message:</source>
        <translation>پەیام:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    <message>
        <source>Yes</source>
        <translation>بەڵێ</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>سەرجەم</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Date</source>
        <translation>رێکەت</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>ناوونیشان</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;هەناردن</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>هەڵبژاردنەکان:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>زانیاری</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ئاگاداری</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>هەڵە</translation>
    </message>
</context>
</TS>
